@@ -46,6 +46,8 @@ guint32             broadway_server_grab_pointer             (BroadwayServer   *
 guint32             broadway_server_ungrab_pointer           (BroadwayServer   *server,
 							      guint32           time_);
 gint32              broadway_server_get_mouse_toplevel       (BroadwayServer   *server);
+void                broadway_server_set_show_keyboard        (BroadwayServer   *server,
+                                                              gboolean          show);
 guint32             broadway_server_new_window               (BroadwayServer   *server,
 							      int               x,
 							      int               y,
@@ -58,6 +60,10 @@ gboolean            broadway_server_window_show              (BroadwayServer   *
 							      gint              id);
 gboolean            broadway_server_window_hide              (BroadwayServer   *server,
 							      gint              id);
+void                broadway_server_window_raise             (BroadwayServer   *server,
+							      gint              id);
+void                broadway_server_window_lower             (BroadwayServer   *server,
+							      gint              id);
 void                broadway_server_window_set_transient_for (BroadwayServer   *server,
 							      gint              id,
 							      gint              parent);
@@ -78,5 +84,12 @@ gboolean            broadway_server_window_move_resize       (BroadwayServer   *
 							      int               y,
 							      int               width,
 							      int               height);
+void                broadway_server_focus_window             (BroadwayServer   *server,
+                                                              gint              new_focused_window);
+cairo_surface_t * broadway_server_open_surface (BroadwayServer *server,
+						guint32 id,
+						char *name,
+						int width,
+						int height);
 
 #endif /* __BROADWAY_SERVER__ */
