@@ -192,6 +192,12 @@ struct _GdkWindow
   gint y;
 
   GdkEventMask event_mask;
+  guint8 window_type;
+
+  guint8 depth;
+  guint8 resize_count;
+
+  gint8 toplevel_window_type;
 
   GList *filters;
   GList *children;
@@ -204,15 +210,11 @@ struct _GdkWindow
   cairo_region_t *update_area;
   guint update_freeze_count;
 
-  guint8 window_type;
-  guint8 depth;
-  guint8 resize_count;
-
-  gint8 toplevel_window_type;
-  guint8 alpha;
-
   GdkWindowState state;
 
+  guint8 alpha;
+  guint8 fullscreen_mode;
+
   guint guffaw_gravity : 1;
   guint input_only : 1;
   guint modal_hint : 1;
@@ -234,7 +236,6 @@ struct _GdkWindow
   guint in_update : 1;
   guint geometry_dirty : 1;
   guint event_compression : 1;
-  GdkFullscreenMode fullscreen_mode;
 
   /* The GdkWindow that has the impl, ref:ed if another window.
    * This ref is required to keep the wrapper of the impl window alive
@@ -246,6 +247,8 @@ struct _GdkWindow
   gint abs_x, abs_y; /* Absolute offset in impl */
   gint width, height;
 
+  guint num_offscreen_children;
+
   /* The clip region is the part of the window, in window coordinates
      that is fully or partially (i.e. semi transparently) visible in
      the window hierarchy from the toplevel and down */
@@ -272,8 +275,6 @@ struct _GdkWindow
   gulong device_added_handler_id;
   gulong device_changed_handler_id;
 
-  guint num_offscreen_children;
-
   GdkFrameClock *frame_clock; /* NULL to use from parent or default */
   GdkWindowInvalidateHandlerFunc invalidate_handler;
 };
