@@ -30,9 +30,11 @@
 
 #include <math.h>
 
+#include "fallback-c89.c"
+
 /* LIMITATIONS:
  *
- * Offscreen windows can't be the child of a foreign window,
+ * Offscreen windows can’t be the child of a foreign window,
  *   nor contain foreign windows
  * GDK_POINTER_MOTION_HINT_MASK isn't effective
  */
