@@ -195,7 +195,7 @@ _gdk_screen_close (GdkScreen *screen)
 }
 
 /* Fallback used when the monitor "at" a point or window
- * doesn't exist.
+ * doesn’t exist.
  */
 static gint
 get_nearest_monitor (GdkScreen *screen,
@@ -394,7 +394,7 @@ gdk_screen_height_mm (void)
  *   previously set default font options.
  *
  * Sets the default font options for the screen. These
- * options will be set on any #PangoContext's newly created
+ * options will be set on any #PangoContext’s newly created
  * with gdk_pango_context_get_for_screen(). Changing the
  * default set of font options does not affect contexts that
  * have already been created.
@@ -443,7 +443,7 @@ gdk_screen_get_font_options (GdkScreen *screen)
 /**
  * gdk_screen_set_resolution:
  * @screen: a #GdkScreen
- * @dpi: the resolution in "dots per inch". (Physical inches aren't actually
+ * @dpi: the resolution in “dots per inch”. (Physical inches aren’t actually
  *   involved; the terminology is conventional.)
  
  * Sets the resolution for font handling on the screen. This is a
@@ -687,7 +687,7 @@ gdk_screen_get_n_monitors (GdkScreen *screen)
  * @screen: a #GdkScreen.
  *
  * Gets the primary monitor for @screen.  The primary monitor
- * is considered the monitor where the 'main desktop' lives.
+ * is considered the monitor where the “main desktop” lives.
  * While normal application windows typically allow the window
  * manager to place the windows, specialized desktop applications
  * such as panels should place themselves on the primary monitor.
@@ -814,7 +814,7 @@ gdk_screen_get_monitor_geometry (GdkScreen    *screen,
  *     the monitor workarea
  *
  * Retrieves the #GdkRectangle representing the size and position of
- * the "work area" on a monitor within the entire screen area.
+ * the “work area” on a monitor within the entire screen area.
  *
  * The work area should be considered when positioning menus and
  * similar popups, to avoid placing them below panels, docks or other
@@ -846,7 +846,7 @@ gdk_screen_get_monitor_workarea (GdkScreen    *screen,
  * For example, a visual might support 24-bit color, or 8-bit color,
  * and might expect pixels to be in a certain format.
  *
- * Call g_list_free() on the return value when you're finished with it.
+ * Call g_list_free() on the return value when you’re finished with it.
  *
  * Return value: (transfer container) (element-type GdkVisual):
  *     a list of visuals; the list must be freed, but not its contents
@@ -865,7 +865,7 @@ gdk_screen_list_visuals (GdkScreen *screen)
  * gdk_screen_get_system_visual:
  * @screen: a #GdkScreen.
  *
- * Get the system's default visual for @screen.
+ * Get the system’s default visual for @screen.
  * This is the visual for the root window of the display.
  * The return value should not be freed.
  *
@@ -889,7 +889,7 @@ gdk_screen_get_system_visual (GdkScreen * screen)
  * The windowing system on which GTK+ is running
  * may not support this capability, in which case %NULL will
  * be returned. Even if a non-%NULL value is returned, its
- * possible that the window's alpha channel won't be honored
+ * possible that the window’s alpha channel won’t be honored
  * when displaying the window on the screen: in particular, for
  * X an appropriate windowing manager and compositing manager
  * must be running to provide appropriate display.
@@ -912,36 +912,6 @@ gdk_screen_get_rgba_visual (GdkScreen *screen)
   return GDK_SCREEN_GET_CLASS (screen)->get_rgba_visual (screen);
 }
 
-/**
- * gdk_screen_get_preferred_visual:
- * @screen: a #GdkScreen
- *
- * Returns the visual that is preferred when creating windows.
- *
- * This will be the visual returned by gdk_screen_get_rgba_visual()
- * unless that is not available, or unless the environment
- * variable <envar>GDK_RGBA</envar> is set to 0.
- *
- * Return value: (transfer none): the preferred visual to use
- *     for windows
- *
- * Since: 3.12
- */
-GdkVisual *
-gdk_screen_get_preferred_visual (GdkScreen *screen)
-{
-  GdkVisual *visual;
-
-  g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
-
-  visual = gdk_screen_get_rgba_visual (screen);
-
-  if (visual == NULL || g_strcmp0 (g_getenv ("GDK_RGBA"), "0") == 0)
-    visual = gdk_screen_get_system_visual (screen);
-
-  return visual;
-}
-
 /**
  * gdk_screen_is_composited:
  * @screen: a #GdkScreen
@@ -989,12 +959,12 @@ gdk_screen_make_display_name (GdkScreen *screen)
  * gdk_screen_get_active_window:
  * @screen: a #GdkScreen
  *
- * Returns the screen's currently active window.
+ * Returns the screen’s currently active window.
  *
  * On X11, this is done by inspecting the _NET_ACTIVE_WINDOW property
- * on the root window, as described in the <ulink
- * url="http://www.freedesktop.org/Standards/wm-spec">Extended Window
- * Manager Hints</ulink>. If there is no currently currently active
+ * on the root window, as described in the
+ * [Extended Window Manager Hints](http://www.freedesktop.org/Standards/wm-spec).
+ * If there is no currently currently active
  * window, or the window manager does not support the
  * _NET_ACTIVE_WINDOW hint, this function returns %NULL.
  *
@@ -1020,13 +990,13 @@ gdk_screen_get_active_window (GdkScreen *screen)
  * gdk_screen_get_window_stack:
  * @screen: a #GdkScreen
  *
- * Returns a #GList of #GdkWindow<!-- -->s representing the current
+ * Returns a #GList of #GdkWindows representing the current
  * window stack.
  *
  * On X11, this is done by inspecting the _NET_CLIENT_LIST_STACKING
- * property on the root window, as described in the <ulink
- * url="http://www.freedesktop.org/Standards/wm-spec">Extended Window
- * Manager Hints</ulink>. If the window manager does not support the
+ * property on the root window, as described in the
+ * [Extended Window Manager Hints](http://www.freedesktop.org/Standards/wm-spec).
+ * If the window manager does not support the
  * _NET_CLIENT_LIST_STACKING hint, this function returns %NULL.
  *
  * On other platforms, this function may return %NULL, depending on whether
@@ -1037,7 +1007,7 @@ gdk_screen_get_active_window (GdkScreen *screen)
  * its windows unrefed using g_object_unref() when no longer needed.
  *
  * Return value: (transfer full) (element-type GdkWindow):
- *     a list of #GdkWindow<!-- -->s for the current window stack,
+ *     a list of #GdkWindows for the current window stack,
  *               or %NULL.
  *
  * Since: 2.10
@@ -1089,7 +1059,7 @@ gdk_screen_get_setting (GdkScreen   *screen,
  * on very high density outputs this can be a higher value (often 2).
  *
  * This can be used if you want to create pixel based data for a
- * particula monitor, but most of the time you're drawing to a window
+ * particula monitor, but most of the time you’re drawing to a window
  * where it is better to use gdk_window_get_scale_factor() instead.
  *
  * Since: 3.10
