@@ -292,6 +292,14 @@ struct _GdkWindowImplClass
                                            GdkAtom         property);
 
   gint         (* get_scale_factor)       (GdkWindow      *window);
+
+  void         (* set_opaque_region)      (GdkWindow      *window,
+                                           cairo_region_t *region);
+  void         (* set_shadow_width)       (GdkWindow      *window,
+                                           gint            left,
+                                           gint            right,
+                                           gint            top,
+                                           gint            bottom);
 };
 
 /* Interface Functions */
