@@ -68,6 +68,8 @@ struct _GdkWaylandScreen
 
   GHashTable *settings;
   GsdXftSettings xft_settings;
+
+  guint32    shell_capabilities;
 };
 
 struct _GdkWaylandScreenClass
@@ -604,6 +606,28 @@ init_settings (GdkScreen *screen)
   update_xft_settings (screen);
 }
 
+static void
+gtk_shell_handle_capabilities (void             *data,
+			       struct gtk_shell *shell,
+			       uint32_t          capabilities)
+{
+  GdkWaylandScreen *screen_wayland = data;
+
+  screen_wayland->shell_capabilities = capabilities;
+}
+
+struct gtk_shell_listener gdk_screen_gtk_shell_listener = {
+  gtk_shell_handle_capabilities
+};
+
+void
+_gdk_wayland_screen_set_has_gtk_shell (GdkScreen *screen)
+{
+  GdkWaylandDisplay *wayland_display = GDK_WAYLAND_DISPLAY (GDK_WAYLAND_SCREEN (screen)->display);
+
+  gtk_shell_add_listener (wayland_display->gtk_shell, &gdk_screen_gtk_shell_listener, screen);
+}
+
 static void
 set_value_from_entry (GdkScreen        *screen,
                       TranslationEntry *entry,
@@ -657,6 +681,18 @@ set_value_from_entry (GdkScreen        *screen,
     }
 }
 
+static gboolean
+set_capability_setting (GdkScreen                 *screen,
+			GValue                    *value,
+			enum gtk_shell_capability  test)
+{
+  GdkWaylandScreen *wayland_screen = GDK_WAYLAND_SCREEN (screen);
+
+  g_value_set_boolean (value, (wayland_screen->shell_capabilities & test) == test);
+
+  return TRUE;
+}
+
 static gboolean
 gdk_wayland_screen_get_setting (GdkScreen   *screen,
 				const gchar *name,
@@ -673,6 +709,21 @@ gdk_wayland_screen_get_setting (GdkScreen   *screen,
       return TRUE;
    }
 
+  if (strcmp (name, "gtk-shell-shows-app-menu") == 0)
+    return set_capability_setting (screen, value, GTK_SHELL_CAPABILITY_GLOBAL_APP_MENU);
+
+  if (strcmp (name, "gtk-shell-shows-menubar") == 0)
+    return set_capability_setting (screen, value, GTK_SHELL_CAPABILITY_GLOBAL_MENU_BAR);
+
+  if (strcmp (name, "gtk-shell-shows-desktop") == 0)
+    return set_capability_setting (screen, value, GTK_SHELL_CAPABILITY_DESKTOP_ICONS);
+
+  if (strcmp (name, "gtk-dialogs-use-header") == 0)
+    {
+      g_value_set_boolean (value, TRUE);
+      return TRUE;
+    }
+
   return FALSE;
 }
 
