@@ -923,21 +923,6 @@ gdk_wayland_window_create_surface (GdkWindow *window)
                            &surface_listener, window);
 }
 
-static void
-xdg_surface_ping (void               *data,
-                  struct xdg_surface *xdg_surface,
-                  uint32_t            serial)
-{
-
-  GdkWindow *window = GDK_WINDOW (data);
-  GdkWaylandDisplay *wayland_display =
-    GDK_WAYLAND_DISPLAY (gdk_window_get_display (window));
-
-  _gdk_wayland_display_update_serial (wayland_display, serial);
-
-  xdg_surface_pong (xdg_surface, serial);
-}
-
 static void
 xdg_surface_configure (void               *data,
                        struct xdg_surface *xdg_surface,
@@ -990,16 +975,16 @@ xdg_surface_request_unset_maximized (void *data,
 }
 
 static void
-xdg_surface_focused_set (void *data,
-                         struct xdg_surface *xdg_surface)
+xdg_surface_activated (void *data,
+                       struct xdg_surface *xdg_surface)
 {
   GdkWindow *window = GDK_WINDOW (data);
   gdk_synthesize_window_state (window, 0, GDK_WINDOW_STATE_FOCUSED);
 }
 
 static void
-xdg_surface_focused_unset (void *data,
-                           struct xdg_surface *xdg_surface)
+xdg_surface_deactivated (void *data,
+                         struct xdg_surface *xdg_surface)
 {
   GdkWindow *window = GDK_WINDOW (data);
   gdk_synthesize_window_state (window, GDK_WINDOW_STATE_FOCUSED, 0);
@@ -1024,14 +1009,13 @@ xdg_surface_delete (void *data,
 }
 
 static const struct xdg_surface_listener xdg_surface_listener = {
-  xdg_surface_ping,
   xdg_surface_configure,
   xdg_surface_request_set_fullscreen,
   xdg_surface_request_unset_fullscreen,
   xdg_surface_request_set_maximized,
   xdg_surface_request_unset_maximized,
-  xdg_surface_focused_set,
-  xdg_surface_focused_unset,
+  xdg_surface_activated,
+  xdg_surface_deactivated,
   xdg_surface_delete,
 };
 
@@ -1049,20 +1033,6 @@ gdk_wayland_window_create_xdg_surface (GdkWindow *window)
   xdg_surface_set_app_id (impl->xdg_surface, gdk_get_program_class ());
 }
 
-static void
-xdg_popup_ping (void             *data,
-                struct xdg_popup *xdg_popup,
-                uint32_t          serial)
-{
-  GdkWindow *window = GDK_WINDOW (data);
-  GdkWaylandDisplay *wayland_display =
-    GDK_WAYLAND_DISPLAY (gdk_window_get_display (window));
-
-  _gdk_wayland_display_update_serial (wayland_display, serial);
-
-  xdg_popup_pong (xdg_popup, serial);
-}
-
 static void
 xdg_popup_done (void             *data,
                 struct xdg_popup *xdg_popup,
@@ -1078,7 +1048,6 @@ xdg_popup_done (void             *data,
 }
 
 static const struct xdg_popup_listener xdg_popup_listener = {
-  xdg_popup_ping,
   xdg_popup_done,
 };
 
