@@ -17,6 +17,7 @@
 
 #include "config.h"
 
+
 #include "gdkx11device-core.h"
 #include "gdkdeviceprivate.h"
 
@@ -25,6 +26,11 @@
 #include "gdkprivate-x11.h"
 #include "gdkasync.h"
 
+#include <math.h>
+
+/* for the use of round() */
+#include "fallback-c89.c"
+
 struct _GdkX11DeviceCore
 {
   GdkDevice parent_instance;
@@ -50,16 +56,16 @@ static void     gdk_x11_device_core_set_window_cursor (GdkDevice *device,
                                                        GdkCursor *cursor);
 static void     gdk_x11_device_core_warp (GdkDevice *device,
                                           GdkScreen *screen,
-                                          gint       x,
-                                          gint       y);
+                                          gdouble    x,
+                                          gdouble    y);
 static void gdk_x11_device_core_query_state (GdkDevice        *device,
                                              GdkWindow        *window,
                                              GdkWindow       **root_window,
                                              GdkWindow       **child_window,
-                                             gint             *root_x,
-                                             gint             *root_y,
-                                             gint             *win_x,
-                                             gint             *win_y,
+                                             gdouble          *root_x,
+                                             gdouble          *root_y,
+                                             gdouble          *win_x,
+                                             gdouble          *win_y,
                                              GdkModifierType  *mask);
 static GdkGrabStatus gdk_x11_device_core_grab   (GdkDevice     *device,
                                                  GdkWindow     *window,
@@ -71,8 +77,8 @@ static GdkGrabStatus gdk_x11_device_core_grab   (GdkDevice     *device,
 static void          gdk_x11_device_core_ungrab (GdkDevice     *device,
                                                  guint32        time_);
 static GdkWindow * gdk_x11_device_core_window_at_position (GdkDevice       *device,
-                                                           gint            *win_x,
-                                                           gint            *win_y,
+                                                           gdouble         *win_x,
+                                                           gdouble         *win_y,
                                                            GdkModifierType *mask,
                                                            gboolean         get_toplevel);
 static void      gdk_x11_device_core_select_window_events (GdkDevice       *device,
@@ -135,10 +141,12 @@ gdk_x11_device_core_get_history (GdkDevice      *device,
   XTimeCoord *xcoords;
   GdkTimeCoord **coords;
   GdkWindow *impl_window;
+  GdkWindowImplX11 *impl;
   int tmp_n_events;
   int i, j;
 
   impl_window = _gdk_window_get_impl_window (window);
+  impl =  GDK_WINDOW_IMPL_X11 (impl_window->impl);
   xcoords = XGetMotionEvents (GDK_WINDOW_XDISPLAY (window),
                               GDK_WINDOW_XID (impl_window),
                               start, stop, &tmp_n_events);
@@ -149,11 +157,13 @@ gdk_x11_device_core_get_history (GdkDevice      *device,
 
   for (i = 0, j = 0; i < tmp_n_events; i++)
     {
-      if (impl_coord_in_window (window, xcoords[i].x, xcoords[i].y))
+      if (impl_coord_in_window (window,
+                                xcoords[i].x / impl->window_scale,
+                                xcoords[i].y / impl->window_scale))
         {
           coords[j]->time = xcoords[i].time;
-          coords[j]->axes[0] = xcoords[i].x - window->abs_x;
-          coords[j]->axes[1] = xcoords[i].y - window->abs_y;
+          coords[j]->axes[0] = (double)xcoords[i].x / impl->window_scale - window->abs_x;
+          coords[j]->axes[1] = (double)xcoords[i].y / impl->window_scale - window->abs_y;
           j++;
         }
     }
@@ -192,14 +202,14 @@ gdk_x11_device_core_get_state (GdkDevice       *device,
                                gdouble         *axes,
                                GdkModifierType *mask)
 {
-  gint x_int, y_int;
+  gdouble x, y;
 
-  gdk_window_get_device_position (window, device, &x_int, &y_int, mask);
+  gdk_window_get_device_position_double (window, device, &x, &y, mask);
 
   if (axes)
     {
-      axes[0] = x_int;
-      axes[1] = y_int;
+      axes[0] = x;
+      axes[1] = y;
     }
 }
 
@@ -223,8 +233,8 @@ gdk_x11_device_core_set_window_cursor (GdkDevice *device,
 static void
 gdk_x11_device_core_warp (GdkDevice *device,
                           GdkScreen *screen,
-                          gint       x,
-                          gint       y)
+                          gdouble    x,
+                          gdouble    y)
 {
   Display *xdisplay;
   Window dest;
@@ -232,7 +242,9 @@ gdk_x11_device_core_warp (GdkDevice *device,
   xdisplay = GDK_DISPLAY_XDISPLAY (gdk_device_get_display (device));
   dest = GDK_WINDOW_XID (gdk_screen_get_root_window (screen));
 
-  XWarpPointer (xdisplay, None, dest, 0, 0, 0, 0, x, y);
+  XWarpPointer (xdisplay, None, dest, 0, 0, 0, 0,
+                round (x * GDK_X11_SCREEN (screen)->window_scale),
+                round (y * GDK_X11_SCREEN (screen)->window_scale));
 }
 
 static void
@@ -240,12 +252,13 @@ gdk_x11_device_core_query_state (GdkDevice        *device,
                                  GdkWindow        *window,
                                  GdkWindow       **root_window,
                                  GdkWindow       **child_window,
-                                 gint             *root_x,
-                                 gint             *root_y,
-                                 gint             *win_x,
-                                 gint             *win_y,
+                                 gdouble          *root_x,
+                                 gdouble          *root_y,
+                                 gdouble          *win_x,
+                                 gdouble          *win_y,
                                  GdkModifierType  *mask)
 {
+  GdkWindowImplX11 *impl = GDK_WINDOW_IMPL_X11 (window->impl);
   GdkDisplay *display;
   GdkScreen *default_screen;
   Window xroot_window, xchild_window;
@@ -291,16 +304,16 @@ gdk_x11_device_core_query_state (GdkDevice        *device,
     *child_window = gdk_x11_window_lookup_for_display (display, xchild_window);
 
   if (root_x)
-    *root_x = xroot_x;
+    *root_x = (double)xroot_x / impl->window_scale;
 
   if (root_y)
-    *root_y = xroot_y;
+    *root_y = (double)xroot_y / impl->window_scale;
 
   if (win_x)
-    *win_x = xwin_x;
+    *win_x = (double)xwin_x / impl->window_scale;
 
   if (win_y)
-    *win_y = xwin_y;
+    *win_y = (double)xwin_y / impl->window_scale;
 
   if (mask)
     *mask = xmask;
@@ -408,11 +421,12 @@ gdk_x11_device_core_ungrab (GdkDevice *device,
 
 static GdkWindow *
 gdk_x11_device_core_window_at_position (GdkDevice       *device,
-                                        gint            *win_x,
-                                        gint            *win_y,
+                                        gdouble         *win_x,
+                                        gdouble         *win_y,
                                         GdkModifierType *mask,
                                         gboolean         get_toplevel)
 {
+  GdkWindowImplX11 *impl;
   GdkDisplay *display;
   GdkScreen *screen;
   Display *xdisplay;
@@ -464,6 +478,7 @@ gdk_x11_device_core_window_at_position (GdkDevice       *device,
       for (list = toplevels; list != NULL; list = g_list_next (list))
         {
           window = GDK_WINDOW (list->data);
+          impl = GDK_WINDOW_IMPL_X11 (window->impl);
           xwindow = GDK_WINDOW_XID (window);
           gdk_x11_display_error_trap_push (display);
           XQueryPointer (xdisplay, xwindow,
@@ -479,7 +494,7 @@ gdk_x11_device_core_window_at_position (GdkDevice       *device,
               break;
             }
           gdk_window_get_geometry (window, NULL, NULL, &width, &height);
-          if (winx >= 0 && winy >= 0 && winx < width && winy < height)
+          if (winx >= 0 && winy >= 0 && winx < width * impl->window_scale && winy < height * impl->window_scale)
             {
               /* A childless toplevel, or below another window? */
               XSetWindowAttributes attributes;
@@ -532,12 +547,15 @@ gdk_x11_device_core_window_at_position (GdkDevice       *device,
   gdk_x11_display_ungrab (display);
 
   window = gdk_x11_window_lookup_for_display (display, last);
+  impl = NULL;
+  if (window)
+    impl = GDK_WINDOW_IMPL_X11 (window->impl);
 
   if (win_x)
-    *win_x = (window) ? xwin_x : -1;
+    *win_x = (window) ? (double)xwin_x / impl->window_scale : -1;
 
   if (win_y)
-    *win_y = (window) ? xwin_y : -1;
+    *win_y = (window) ? (double)xwin_y / impl->window_scale : -1;
 
   if (mask)
     *mask = xmask;
