@@ -94,7 +94,7 @@ static guint adjustment_signals[LAST_SIGNAL] = { 0 };
 
 static guint64 adjustment_changed_stamp = 0; /* protected by global gdk lock */
 
-G_DEFINE_TYPE (GtkAdjustment, gtk_adjustment, G_TYPE_INITIALLY_UNOWNED)
+G_DEFINE_TYPE_WITH_PRIVATE (GtkAdjustment, gtk_adjustment, G_TYPE_INITIALLY_UNOWNED)
 
 static void
 gtk_adjustment_class_init (GtkAdjustmentClass *class)
@@ -147,7 +147,7 @@ gtk_adjustment_class_init (GtkAdjustmentClass *class)
    * 
    * The maximum value of the adjustment. 
    * Note that values will be restricted by 
-   * <literal>upper - page-size</literal> if the page-size 
+   * `upper - page-size` if the page-size 
    * property is nonzero.
    *
    * Since: 2.4
@@ -246,16 +246,12 @@ gtk_adjustment_class_init (GtkAdjustmentClass *class)
 		  NULL, NULL,
 		  _gtk_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-
-  g_type_class_add_private (class, sizeof (GtkAdjustmentPrivate));
 }
 
 static void
 gtk_adjustment_init (GtkAdjustment *adjustment)
 {
-  adjustment->priv = G_TYPE_INSTANCE_GET_PRIVATE (adjustment,
-                                                  GTK_TYPE_ADJUSTMENT,
-                                                  GtkAdjustmentPrivate);
+  adjustment->priv = gtk_adjustment_get_instance_private (adjustment);
 }
 
 static void
@@ -472,7 +468,7 @@ gtk_adjustment_get_lower (GtkAdjustment *adjustment)
  * When setting multiple adjustment properties via their individual
  * setters, multiple #GtkAdjustment::changed signals will be emitted. However, since
  * the emission of the #GtkAdjustment::changed signal is tied to the emission of the
- * #GObject::notify signals of the changed properties, it's possible
+ * #GObject::notify signals of the changed properties, it’s possible
  * to compress the #GtkAdjustment::changed signals into one by calling
  * g_object_freeze_notify() and g_object_thaw_notify() around the
  * calls to the individual setters.
@@ -519,7 +515,7 @@ gtk_adjustment_get_upper (GtkAdjustment *adjustment)
  * Sets the maximum value of the adjustment.
  *
  * Note that values will be restricted by
- * <literal>upper - page-size</literal> if the page-size
+ * `upper - page-size` if the page-size
  * property is nonzero.
  *
  * See gtk_adjustment_set_lower() about how to compress multiple
