@@ -32,20 +32,20 @@
  *
  * The design of GtkAssistant is that it controls what buttons to show
  * and to make sensitive, based on what it knows about the page sequence
- * and the <link linkend="GtkAssistantPageType">type</link> of each page,
+ * and the [type][GtkAssistantPageType] of each page,
  * in addition to state information like the page
- * <link linkend="gtk-assistant-set-page-complete">completion</link>
- * and <link linkend="gtk-assistant-commit">committed</link> status.
+ * [completion][gtk-assistant-set-page-complete]
+ * and [committed][gtk-assistant-commit] status.
  *
- * If you have a case that doesn't quite fit in #GtkAssistants way of
+ * If you have a case that doesn’t quite fit in #GtkAssistants way of
  * handling buttons, you can use the #GTK_ASSISTANT_PAGE_CUSTOM page
  * type and handle buttons yourself.
  *
- * ## GtkAssistant as GtkBuildable
+ * # GtkAssistant as GtkBuildable
  *
  * The GtkAssistant implementation of the #GtkBuildable interface
  * exposes the @action_area as internal children with the name
- * "action_area".
+ * “action_area”.
  *
  * To add pages to an assistant in #GtkBuilder, simply add it as a
  * child to the GtkAssistant object, and set its child properties
@@ -342,7 +342,7 @@ add_action_widgets (GtkAssistant *assistant)
           if (has_default)
             {
               gtk_widget_grab_default (child);
-              gtk_style_context_add_class (gtk_widget_get_style_context (child), "suggested-action");
+              gtk_style_context_add_class (gtk_widget_get_style_context (child), GTK_STYLE_CLASS_SUGGESTED_ACTION);
             }
         }
       g_list_free (children);
@@ -1805,7 +1805,7 @@ gtk_assistant_insert_page (GtkAssistant *assistant,
  * @page_num: the index of a page in the @assistant,
  *     or -1 to remove the last page
  *
- * Removes the @page_num's page from @assistant.
+ * Removes the @page_num’s page from @assistant.
  *
  * Since: 3.2
  */
@@ -2164,7 +2164,7 @@ gtk_assistant_do_set_page_header_image (GtkAssistant *assistant,
  * Gets the header image for @page.
  *
  * Return value: (transfer none): the header image for @page,
- *     or %NULL if there's no header image for the page
+ *     or %NULL if there’s no header image for the page
  *
  * Since: 2.10
  *
@@ -2255,7 +2255,7 @@ gtk_assistant_do_set_page_side_image (GtkAssistant *assistant,
  * Gets the side image for @page.
  *
  * Return value: (transfer none): the side image for @page,
- *     or %NULL if there's no side image for the page
+ *     or %NULL if there’s no side image for the page
  *
  * Since: 2.10
  *
