@@ -29,10 +29,10 @@
  * The #GtkCellAreaBox renders cell renderers into a row or a column
  * depending on its #GtkOrientation.
  *
- * GtkCellAreaBox uses a notion of <emphasis>packing</emphasis>. Packing
+ * GtkCellAreaBox uses a notion of packing. Packing
  * refers to adding cell renderers with reference to a particular position
  * in a #GtkCellAreaBox. There are two reference positions: the
- * <emphasis>start</emphasis> and the <emphasis>end</emphasis> of the box.
+ * start and the end of the box.
  * When the #GtkCellAreaBox is oriented in the %GTK_ORIENTATION_VERTICAL
  * orientation, the start is defined as the top of the box and the end is
  * defined as the bottom. In the %GTK_ORIENTATION_HORIZONTAL orientation
@@ -40,7 +40,7 @@
  * side.
  *
  * Alignments of #GtkCellRenderers rendered in adjacent rows can be
- * configured by configuring the #GtkCellAreaBox:align child cell property
+ * configured by configuring the #GtkCellAreaBox align child cell property
  * with gtk_cell_area_cell_set_property() or by specifying the "align"
  * argument to gtk_cell_area_box_pack_start() and gtk_cell_area_box_pack_end().
  */
@@ -235,18 +235,17 @@ enum {
 };
 
 G_DEFINE_TYPE_WITH_CODE (GtkCellAreaBox, gtk_cell_area_box, GTK_TYPE_CELL_AREA,
+                         G_ADD_PRIVATE (GtkCellAreaBox)
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_CELL_LAYOUT,
                                                 gtk_cell_area_box_cell_layout_init)
-                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL));
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL))
 
 static void
 gtk_cell_area_box_init (GtkCellAreaBox *box)
 {
   GtkCellAreaBoxPrivate *priv;
 
-  box->priv = G_TYPE_INSTANCE_GET_PRIVATE (box,
-                                           GTK_TYPE_CELL_AREA_BOX,
-                                           GtkCellAreaBoxPrivate);
+  box->priv = gtk_cell_area_box_get_instance_private (box);
   priv = box->priv;
 
   priv->orientation = GTK_ORIENTATION_HORIZONTAL;
@@ -383,8 +382,6 @@ gtk_cell_area_box_class_init (GtkCellAreaBoxClass *class)
                                                  "reference to the start or end of the cell area"),
                                               GTK_TYPE_PACK_TYPE, GTK_PACK_START,
                                               GTK_PARAM_READWRITE));
-
-  g_type_class_add_private (object_class, sizeof (GtkCellAreaBoxPrivate));
 }
 
 
