@@ -30,7 +30,7 @@
  * #GtkTreeModel rows that are requested and rendered in the same context.
  *
  * #GtkCellLayout widgets can create any number of contexts in which to
- * request and render groups of data rows. However, it's important that the
+ * request and render groups of data rows. However, it’s important that the
  * same context which was used to request sizes for a given #GtkTreeModel
  * row also be used for the same row when calling other #GtkCellArea APIs
  * such as gtk_cell_area_render() and gtk_cell_area_event().
@@ -80,14 +80,12 @@ enum {
   PROP_NAT_HEIGHT
 };
 
-G_DEFINE_TYPE (GtkCellAreaContext, gtk_cell_area_context, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GtkCellAreaContext, gtk_cell_area_context, G_TYPE_OBJECT)
 
 static void
 gtk_cell_area_context_init (GtkCellAreaContext *context)
 {
-  context->priv = G_TYPE_INSTANCE_GET_PRIVATE (context,
-                                               GTK_TYPE_CELL_AREA_CONTEXT,
-                                               GtkCellAreaContextPrivate);
+  context->priv = gtk_cell_area_context_get_instance_private (context);
 }
 
 static void
@@ -194,8 +192,6 @@ gtk_cell_area_context_class_init (GtkCellAreaContextClass *class)
                                                      G_MAXINT,
                                                      -1,
                                                      G_PARAM_READABLE));
-
-  g_type_class_add_private (object_class, sizeof (GtkCellAreaContextPrivate));
 }
 
 /*************************************************************
@@ -334,7 +330,7 @@ gtk_cell_area_context_real_allocate (GtkCellAreaContext *context,
  * fetch information about the area it is being used for.
  *
  * For instance at #GtkCellAreaContextClass.allocate() time
- * it's important to know details about any cell spacing
+ * it’s important to know details about any cell spacing
  * that the #GtkCellArea is configured with in order to
  * compute a proper allocation.
  *
