@@ -406,7 +406,7 @@ gtk_cell_renderer_pixbuf_set_property (GObject      *object,
  * parameters using object properties. Object properties can be set
  * globally (with g_object_set()). Also, with #GtkTreeViewColumn, you
  * can bind a property to a value in a #GtkTreeModel. For example, you
- * can bind the "pixbuf" property on the cell renderer to a pixbuf value
+ * can bind the “pixbuf” property on the cell renderer to a pixbuf value
  * in the model, thus rendering a different image in each row of the
  * #GtkTreeView.
  * 
@@ -531,15 +531,10 @@ gtk_cell_renderer_pixbuf_render (GtkCellRenderer      *cell,
   context = gtk_widget_get_style_context (widget);
   gtk_style_context_save (context);
 
-  state = GTK_STATE_FLAG_NORMAL;
+  state = gtk_cell_renderer_get_state (cell, widget, flags);
 
-  if (!gtk_widget_get_sensitive (widget) ||
-      !gtk_cell_renderer_get_sensitive (cell))
-    state |= GTK_STATE_FLAG_INSENSITIVE;
-  else if (priv->follow_state && 
-	   (flags & (GTK_CELL_RENDERER_SELECTED |
-		     GTK_CELL_RENDERER_PRELIT)) != 0)
-    state = gtk_cell_renderer_get_state (cell, widget, flags);
+  if (!priv->follow_state)
+    state &= ~(GTK_STATE_FLAG_FOCUSED | GTK_STATE_FLAG_PRELIGHT | GTK_STATE_FLAG_SELECTED);
 
   gtk_style_context_set_state (context, state);
   gtk_style_context_add_class (context, GTK_STYLE_CLASS_IMAGE);
