@@ -153,12 +153,13 @@ enum
   PROP_FIT_MODEL
 };
 
-G_DEFINE_TYPE_WITH_CODE (GtkCellView, gtk_cell_view, GTK_TYPE_WIDGET, 
+G_DEFINE_TYPE_WITH_CODE (GtkCellView, gtk_cell_view, GTK_TYPE_WIDGET,
+                         G_ADD_PRIVATE (GtkCellView)
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_CELL_LAYOUT,
 						gtk_cell_view_cell_layout_init)
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
 						gtk_cell_view_buildable_init)
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL));
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL))
 
 static void
 gtk_cell_view_class_init (GtkCellViewClass *klass)
@@ -322,8 +323,6 @@ gtk_cell_view_class_init (GtkCellViewClass *klass)
   ADD_SET_PROP ("background-set", PROP_BACKGROUND_SET,
                 P_("Background set"),
                 P_("Whether this tag affects the background color"));
-
-  g_type_class_add_private (gobject_class, sizeof (GtkCellViewPrivate));
 }
 
 static void
@@ -533,16 +532,10 @@ gtk_cell_view_set_property (GObject      *object,
 static void
 gtk_cell_view_init (GtkCellView *cellview)
 {
-  GtkCellViewPrivate *priv;
-
-  cellview->priv = G_TYPE_INSTANCE_GET_PRIVATE (cellview,
-                                                GTK_TYPE_CELL_VIEW,
-                                                GtkCellViewPrivate);
-  priv = cellview->priv;
+  cellview->priv = gtk_cell_view_get_instance_private (cellview);
+  cellview->priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 
   gtk_widget_set_has_window (GTK_WIDGET (cellview), FALSE);
-
-  priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 }
 
 static void
@@ -1026,8 +1019,7 @@ gtk_cell_view_new_with_text (const gchar *text)
  *
  * Creates a new #GtkCellView widget, adds a #GtkCellRendererText 
  * to it, and makes it show @markup. The text can be
- * marked up with the <link linkend="PangoMarkupFormat">Pango text 
- * markup language</link>.
+ * marked up with the [Pango text markup language][PangoMarkupFormat].
  *
  * Return value: A newly created #GtkCellView widget.
  *
@@ -1180,7 +1172,7 @@ gtk_cell_view_get_model (GtkCellView *cell_view)
  *
  * Sets the row of the model that is currently displayed
  * by the #GtkCellView. If the path is unset, then the
- * contents of the cellview "stick" at their last value;
+ * contents of the cellview “stick” at their last value;
  * this is not normally a desired result, but may be
  * a needed intermediate state if say, the model for
  * the #GtkCellView becomes temporarily empty.
@@ -1443,7 +1435,7 @@ gtk_cell_view_get_fit_model (GtkCellView     *cell_view)
  * Sets whether @cell_view should request space to fit the entire #GtkTreeModel.
  *
  * This is used by #GtkComboBox to ensure that the cell view displayed on
- * the combo box's button always gets enough space and does not resize
+ * the combo box’s button always gets enough space and does not resize
  * when selection changes.
  *
  * Since: 3.0
