@@ -26,8 +26,8 @@
 #include "gtkcheckmenuitem.h"
 #include "gtkmenuitemprivate.h"
 #include "gtkaccellabel.h"
-#include "gtkactivatable.h"
-#include "gtktoggleaction.h"
+#include "deprecated/gtkactivatable.h"
+#include "deprecated/gtktoggleaction.h"
 #include "gtkmarshalers.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
@@ -314,7 +314,7 @@ gtk_check_menu_item_new_with_mnemonic (const gchar *label)
  * @check_menu_item: a #GtkCheckMenuItem.
  * @is_active: boolean value indicating whether the check box is active.
  *
- * Sets the active state of the menu item's check box.
+ * Sets the active state of the menu item’s check box.
  */
 void
 gtk_check_menu_item_set_active (GtkCheckMenuItem *check_menu_item,
@@ -381,16 +381,16 @@ gtk_check_menu_item_toggled (GtkCheckMenuItem *check_menu_item)
 /**
  * gtk_check_menu_item_set_inconsistent:
  * @check_menu_item: a #GtkCheckMenuItem
- * @setting: %TRUE to display an "inconsistent" third state check
+ * @setting: %TRUE to display an “inconsistent” third state check
  *
  * If the user has selected a range of elements (such as some text or
  * spreadsheet cells) that are affected by a boolean setting, and the
  * current values in that range are inconsistent, you may want to
- * display the check in an "in between" state. This function turns on
- * "in between" display.  Normally you would turn off the inconsistent
+ * display the check in an “in between” state. This function turns on
+ * “in between” display.  Normally you would turn off the inconsistent
  * state again if the user explicitly selects a setting. This has to be
  * done manually, gtk_check_menu_item_set_inconsistent() only affects
- * visual appearance, it doesn't affect the semantics of the widget.
+ * visual appearance, it doesn’t affect the semantics of the widget.
  * 
  **/
 void
