@@ -43,6 +43,7 @@
 #include "gtksettings.h"
 #include "gtktypebuiltins.h"
 #include "deprecated/gtkstock.h"
+#include "gtksizegroup.h"
 
 /**
  * SECTION:gtkdialog
@@ -52,12 +53,12 @@
  *
  * Dialog boxes are a convenient way to prompt the user for a small amount
  * of input, e.g. to display a message, ask a question, or anything else
- * that does not require extensive effort on the user's part.
+ * that does not require extensive effort on the user’s part.
  *
  * GTK+ treats a dialog as a window split vertically. The top section is a
  * #GtkVBox, and is where widgets such as a #GtkLabel or a #GtkEntry should
  * be packed. The bottom area is known as the
- * <quote>action_area</quote>. This is generally used for
+ * “action area”. This is generally used for
  * packing buttons into the dialog which may perform functions such as
  * cancel, ok, or apply.
  *
@@ -66,11 +67,11 @@
  * recommended; it allows you to set the dialog title, some convenient
  * flags, and add simple buttons.
  *
- * If 'dialog' is a newly created dialog, the two primary areas of the
+ * If “dialog” is a newly created dialog, the two primary areas of the
  * window can be accessed through gtk_dialog_get_content_area() and
  * gtk_dialog_get_action_area(), as can be seen from the example below.
  *
- * A 'modal' dialog (that is, one which freezes the rest of the application
+ * A “modal” dialog (that is, one which freezes the rest of the application
  * from user input), can be created by calling gtk_window_set_modal() on the
  * dialog. Use the GTK_WINDOW() macro to cast the widget returned from
  * gtk_dialog_new() into a #GtkWindow. When using gtk_dialog_new_with_buttons()
@@ -92,52 +93,55 @@
  * dialog, returning the response ID corresponding to the button the user
  * clicked.
  *
- * For the simple dialog in the following example, in reality you'd probably
- * use #GtkMessageDialog to save yourself some effort. But you'd need to
+ * For the simple dialog in the following example, in reality you’d probably
+ * use #GtkMessageDialog to save yourself some effort. But you’d need to
  * create the dialog contents manually if you had more than a simple message
  * in the dialog.
  *
  * An example for simple GtkDialog usage:
  * |[<!-- language="C" -->
- * /&ast; Function to open a dialog box displaying the message provided. &ast;/
+ * // Function to open a dialog box with a message
  * void
- * quick_message (gchar *message)
+ * quick_message (GtkWindow *parent, gchar *message)
  * {
- *    GtkWidget *dialog, *label, *content_area;
+ *  GtkWidget *dialog, *label, *content_area;
+ *  GtkDialogFlags flags;
  *
- *    /&ast; Create the widgets &ast;/
- *    dialog = gtk_dialog_new_with_buttons ("Message",
- *                                          main_application_window,
- *                                          GTK_DIALOG_DESTROY_WITH_PARENT,
- *                                          _("_OK"),
- *                                          GTK_RESPONSE_NONE,
- *                                          NULL);
- *    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
- *    label = gtk_label_new (message);
+ *  // Create the widgets
+ *  flags = GTK_DIALOG_DESTROY_WITH_PARENT;
+ *  dialog = gtk_dialog_new_with_buttons ("Message",
+ *                                        parent,
+ *                                        flags,
+ *                                        _("_OK"),
+ *                                        GTK_RESPONSE_NONE,
+ *                                        NULL);
+ *  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+ *  label = gtk_label_new (message);
  *
- *    /&ast; Ensure that the dialog box is destroyed when the user responds &ast;/
- *    g_signal_connect_swapped (dialog,
- *                              "response",
- *                              G_CALLBACK (gtk_widget_destroy),
- *                              dialog);
+ *  // Ensure that the dialog box is destroyed when the user responds
  *
- *    /&ast; Add the label, and show everything we've added to the dialog &ast;/
+ *  g_signal_connect_swapped (dialog,
+ *                            "response",
+ *                            G_CALLBACK (gtk_widget_destroy),
+ *                            dialog);
  *
- *    gtk_container_add (GTK_CONTAINER (content_area), label);
- *    gtk_widget_show_all (dialog);
+ *  // Add the label, and show everything we’ve added
+ *
+ *  gtk_container_add (GTK_CONTAINER (content_area), label);
+ *  gtk_widget_show_all (dialog);
  * }
  * ]|
  *
- * ## GtkDialog as GtkBuildable
+ * # GtkDialog as GtkBuildable
  *
  * The GtkDialog implementation of the #GtkBuildable interface exposes the
- * @vbox and @action_area as internal children with the names "vbox" and
- * "action_area".
+ * @vbox and @action_area as internal children with the names “vbox” and
+ * “action_area”.
  *
- * GtkDialog supports a custom &lt;action-widgets&gt; element, which
- * can contain multiple &lt;action-widget&gt; elements. The "response"
- * attribute specifies a numeric response, and the content of the element
- * is the id of widget (which should be a child of the dialogs @action_area).
+ * GtkDialog supports a custom <action-widgets> element, which can contain
+ * multiple <action-widget> elements. The “response” attribute specifies a
+ * numeric response, and the content of the element is the id of widget
+ * (which should be a child of the dialogs @action_area).
  *
  * An example of a #GtkDialog UI definition fragment:
  * |[
@@ -169,6 +173,7 @@ struct _GtkDialogPrivate
   GtkWidget *vbox;
   GtkWidget *headerbar;
   GtkWidget *action_area;
+  GtkSizeGroup *size_group;
 
   gint use_header_bar;
   gboolean constructed;
@@ -377,6 +382,8 @@ add_to_header_bar (GtkDialog *dialog,
   else 
     gtk_header_bar_pack_end (GTK_HEADER_BAR (priv->headerbar), child);
 
+  gtk_size_group_add_widget (priv->size_group, child);
+
   if (response_id == GTK_RESPONSE_CANCEL || response_id == GTK_RESPONSE_CLOSE)
     gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (priv->headerbar), FALSE);
 }
@@ -425,7 +432,7 @@ add_action_widgets (GtkDialog *dialog)
           if (has_default)
             {
               gtk_widget_grab_default (child);
-              gtk_style_context_add_class (gtk_widget_get_style_context (child), "suggested-action");
+              gtk_style_context_add_class (gtk_widget_get_style_context (child), GTK_STYLE_CLASS_SUGGESTED_ACTION);
             }
         }
       g_list_free (children);
@@ -457,6 +464,16 @@ gtk_dialog_constructor (GType                  type,
   return object;
 }
 
+static void
+gtk_dialog_finalize (GObject *obj)
+{
+  GtkDialog *dialog = GTK_DIALOG (obj);
+
+  g_object_unref (dialog->priv->size_group);
+
+  G_OBJECT_CLASS (gtk_dialog_parent_class)->finalize (obj);
+}
+
 static void
 gtk_dialog_class_init (GtkDialogClass *class)
 {
@@ -470,6 +487,7 @@ gtk_dialog_class_init (GtkDialogClass *class)
   gobject_class->constructor  = gtk_dialog_constructor;
   gobject_class->set_property = gtk_dialog_set_property;
   gobject_class->get_property = gtk_dialog_get_property;
+  gobject_class->finalize = gtk_dialog_finalize;
 
   widget_class->map = gtk_dialog_map;
   widget_class->style_updated = gtk_dialog_style_updated;
@@ -502,7 +520,7 @@ gtk_dialog_class_init (GtkDialogClass *class)
    * GtkDialog::close:
    *
    * The ::close signal is a
-   * <link linkend="keybinding-signals">keybinding signal</link>
+   * [keybinding signal][GtkBindingSignal]
    * which gets emitted when the user uses a keybinding to close
    * the dialog.
    *
@@ -628,6 +646,7 @@ gtk_dialog_init (GtkDialog *dialog)
   dialog->priv = gtk_dialog_get_instance_private (dialog);
 
   dialog->priv->use_header_bar = -1;
+  dialog->priv->size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
   gtk_widget_init_template (GTK_WIDGET (dialog));
 
@@ -842,16 +861,18 @@ gtk_dialog_new_empty (const gchar     *title,
  * #GTK_DIALOG_DESTROY_WITH_PARENT flag. Buttons are from left to right,
  * so the first button in the list will be the leftmost button in the dialog.
  *
- * Here's a simple example:
+ * Here’s a simple example:
  * |[<!-- language="C" -->
- *  GtkWidget *dialog = gtk_dialog_new_with_buttons ("My dialog",
- *                                                   main_app_window,
- *                                                   GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
- *                                                   _("_OK"),
- *                                                   GTK_RESPONSE_ACCEPT,
- *                                                   _("_Cancel"),
- *                                                   GTK_RESPONSE_REJECT,
- *                                                   NULL);
+ *  GtkWidget *dialog;
+ *  GtkDialogFlags flags = GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT;
+ *  dialog = gtk_dialog_new_with_buttons ("My dialog",
+ *                                        main_app_window,
+ *                                        flags,
+ *                                        _("_OK"),
+ *                                        GTK_RESPONSE_ACCEPT,
+ *                                        _("_Cancel"),
+ *                                        GTK_RESPONSE_REJECT,
+ *                                        NULL);
  * ]|
  *
  * Return value: a new #GtkDialog
@@ -914,7 +935,7 @@ get_response_data (GtkWidget *widget,
  * Adds an activatable widget to the action area of a #GtkDialog,
  * connecting a signal handler that will emit the #GtkDialog::response
  * signal on the dialog when the widget is activated. The widget is
- * appended to the end of the dialog's action area. If you want to add a
+ * appended to the end of the dialog’s action area. If you want to add a
  * non-activatable widget, simply pack it into the @action_area field
  * of the #GtkDialog struct.
  **/
@@ -945,8 +966,8 @@ gtk_dialog_add_action_widget (GtkDialog *dialog,
  * Adds a button with the given text and sets things up so that
  * clicking the button will emit the #GtkDialog::response signal with
  * the given @response_id. The button is appended to the end of the
- * dialog's action area. The button widget is returned, but usually
- * you don't need it.
+ * dialog’s action area. The button widget is returned, but usually
+ * you don’t need it.
  *
  * Return value: (transfer none): the #GtkButton widget that was added
  **/
@@ -1044,8 +1065,8 @@ gtk_dialog_add_buttons (GtkDialog   *dialog,
  * @response_id: a response ID
  * @setting: %TRUE for sensitive
  *
- * Calls <literal>gtk_widget_set_sensitive (widget, @setting)</literal>
- * for each widget in the dialog's action area with the given @response_id.
+ * Calls `gtk_widget_set_sensitive (widget, @setting)`
+ * for each widget in the dialog’s action area with the given @response_id.
  * A convenient way to sensitize/desensitize dialog buttons.
  **/
 void
@@ -1080,8 +1101,8 @@ gtk_dialog_set_response_sensitive (GtkDialog *dialog,
  * @dialog: a #GtkDialog
  * @response_id: a response ID
  *
- * Sets the last widget in the dialog's action area with the given @response_id
- * as the default widget for the dialog. Pressing "Enter" normally activates
+ * Sets the last widget in the dialog’s action area with the given @response_id
+ * as the default widget for the dialog. Pressing “Enter” normally activates
  * the default widget.
  **/
 void
@@ -1105,7 +1126,7 @@ gtk_dialog_set_default_response (GtkDialog *dialog,
         {
 	  gtk_widget_grab_default (widget);
           if (dialog->priv->constructed && dialog->priv->use_header_bar == 1)
-            gtk_style_context_add_class (gtk_widget_get_style_context (widget), "suggested-action");
+            gtk_style_context_add_class (gtk_widget_get_style_context (widget), GTK_STYLE_CLASS_SUGGESTED_ACTION);
         }
 
       tmp_list = g_list_next (tmp_list);
@@ -1216,7 +1237,7 @@ run_destroy_handler (GtkDialog *dialog, gpointer data)
  * will be modal. You can force gtk_dialog_run() to return at any time by
  * calling gtk_dialog_response() to emit the ::response signal. Destroying
  * the dialog during gtk_dialog_run() is a very bad idea, because your
- * post-run code won't know whether the dialog was destroyed or not.
+ * post-run code won’t know whether the dialog was destroyed or not.
  *
  * After gtk_dialog_run() returns, you are responsible for hiding or
  * destroying the dialog if you wish to do so.
@@ -1368,7 +1389,7 @@ gtk_dialog_get_widget_for_response (GtkDialog *dialog,
  * of a dialog.
  *
  * Returns: the response id of @widget, or %GTK_RESPONSE_NONE
- *  if @widget doesn't have a response id set.
+ *  if @widget doesn’t have a response id set.
  *
  * Since: 2.8
  */
@@ -1449,23 +1470,24 @@ gtk_dialog_set_alternative_button_order_valist (GtkDialog *dialog,
 /**
  * gtk_dialog_set_alternative_button_order:
  * @dialog: a #GtkDialog
- * @first_response_id: a response id used by one @dialog's buttons
- * @...: a list of more response ids of @dialog's buttons, terminated by -1
+ * @first_response_id: a response id used by one @dialog’s buttons
+ * @...: a list of more response ids of @dialog’s buttons, terminated by -1
  *
  * Sets an alternative button order. If the
  * #GtkSettings:gtk-alternative-button-order setting is set to %TRUE,
  * the dialog buttons are reordered according to the order of the
  * response ids passed to this function.
  *
- * By default, GTK+ dialogs use the button order advocated by the Gnome
- * <ulink url="http://library.gnome.org/devel/hig-book/stable/">Human
- * Interface Guidelines</ulink> with the affirmative button at the far
+ * By default, GTK+ dialogs use the button order advocated by the
+ * [GNOME Human Interface Guidelines](http://library.gnome.org/devel/hig-book/stable/)
+ * with the affirmative button at the far
  * right, and the cancel button left of it. But the builtin GTK+ dialogs
- * and #GtkMessageDialog<!-- -->s do provide an alternative button order,
+ * and #GtkMessageDialogs do provide an alternative button order,
  * which is more suitable on some platforms, e.g. Windows.
  *
  * Use this function after adding all the buttons to your dialog, as the
  * following example shows:
+ *
  * |[<!-- language="C" -->
  * cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
  *                                        _("_Cancel"),
@@ -1519,7 +1541,7 @@ gtk_dialog_set_alternative_button_order (GtkDialog *dialog,
  * @dialog: a #GtkDialog
  * @n_params: the number of response ids in @new_order
  * @new_order: (array length=n_params): an array of response ids of
- *     @dialog's buttons
+ *     @dialog’s buttons
  *
  * Sets an alternative button order. If the
  * #GtkSettings:gtk-alternative-button-order setting is set to %TRUE,
