@@ -46,11 +46,11 @@
  * @Title: GtkLayout
  * @See_also: #GtkDrawingArea, #GtkScrolledWindow
  *
- * #GtkLayout is similar to #GtkDrawingArea in that it's a "blank slate"
- * and doesn't do anything but paint a blank background by default. It's
+ * #GtkLayout is similar to #GtkDrawingArea in that it’s a “blank slate”
+ * and doesn’t do anything but paint a blank background by default. It's
  * different in that it supports scrolling natively (you can add it to a
- * #GtkScrolledWindow), and it can contain child widgets, since it's a
- * #GtkContainer. However if you're just going to draw, a #GtkDrawingArea
+ * #GtkScrolledWindow), and it can contain child widgets, since it’s a
+ * #GtkContainer. However if you’re just going to draw, a #GtkDrawingArea
  * is a better choice since it has lower overhead.
  *
  * When handling expose events on a #GtkLayout, you must draw to
@@ -161,6 +161,7 @@ static void gtk_layout_set_hadjustment_values (GtkLayout      *layout);
 static void gtk_layout_set_vadjustment_values (GtkLayout      *layout);
 
 G_DEFINE_TYPE_WITH_CODE (GtkLayout, gtk_layout, GTK_TYPE_CONTAINER,
+                         G_ADD_PRIVATE (GtkLayout)
 			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SCROLLABLE, NULL))
 
 /* Public interface
@@ -171,7 +172,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkLayout, gtk_layout, GTK_TYPE_CONTAINER,
  * @vadjustment: (allow-none): vertical scroll adjustment, or %NULL
  * 
  * Creates a new #GtkLayout. Unless you have a specific adjustment
- * you'd like the layout to use for scrolling, pass %NULL for
+ * you’d like the layout to use for scrolling, pass %NULL for
  * @hadjustment and @vadjustment.
  * 
  * Return value: a new #GtkLayout
@@ -600,7 +601,7 @@ gtk_layout_set_size (GtkLayout     *layout,
  *     @layout, or %NULL
  *
  * Gets the size that has been set on the layout, and that determines
- * the total extents of the layout's scrollbar area. See
+ * the total extents of the layout’s scrollbar area. See
  * gtk_layout_set_size ().
  **/
 void
@@ -696,8 +697,6 @@ gtk_layout_class_init (GtkLayoutClass *class)
   container_class->add = gtk_layout_add;
   container_class->remove = gtk_layout_remove;
   container_class->forall = gtk_layout_forall;
-
-  g_type_class_add_private (class, sizeof (GtkLayoutPrivate));
 }
 
 static void
@@ -831,9 +830,7 @@ gtk_layout_init (GtkLayout *layout)
 {
   GtkLayoutPrivate *priv;
 
-  layout->priv = G_TYPE_INSTANCE_GET_PRIVATE (layout,
-                                              GTK_TYPE_LAYOUT,
-                                              GtkLayoutPrivate);
+  layout->priv = gtk_layout_get_instance_private (layout);
   priv = layout->priv;
 
   priv->children = NULL;
