@@ -165,7 +165,7 @@ module_build_la_path (const gchar *directory,
  * Looks for a dynamically module named @name of type @type in the standard GTK+
  *  module search path.
  * 
- * Return value: the pathname to the found module, or %NULL if it wasn't found.
+ * Return value: the pathname to the found module, or %NULL if it wasn’t found.
  *  Free with g_free().
  **/
 gchar *
@@ -525,17 +525,14 @@ _gtk_modules_init (gint        *argc,
       gtk_argv [*argc] = NULL;
     }
 
-  display_manager = gdk_display_manager_peek ();
-  if (display_manager != NULL)
-    {
-      default_display_opened = gdk_display_get_default () != NULL;
-      g_signal_connect (display_manager, "notify::default-display",
-                        G_CALLBACK (default_display_notify_cb),
-                        NULL);
-      g_signal_connect (display_manager, "display-opened",
-                        G_CALLBACK (display_opened_cb),
-                        NULL);
-    }
+  display_manager = gdk_display_manager_get ();
+  default_display_opened = gdk_display_get_default () != NULL;
+  g_signal_connect (display_manager, "notify::default-display",
+                    G_CALLBACK (default_display_notify_cb),
+                    NULL);
+  g_signal_connect (display_manager, "display-opened",
+                    G_CALLBACK (display_opened_cb),
+                    NULL);
 
   if (gtk_modules_args)
     {
