@@ -60,7 +60,7 @@ _gtk_mount_operation_kill_process (GPid      pid,
                G_IO_ERROR,
                G_IO_ERROR_NOT_SUPPORTED,
                _("Cannot kill process with PID %d. Operation is not implemented."),
-               (int) pid);
+               pid);
   return FALSE;
 }
 
