@@ -36,9 +36,9 @@
  *
  * A GtkPrintSettings object represents the settings of a print dialog in
  * a system-independent way. The main use for this object is that once
- * you've printed you can get a settings object that represents the settings
+ * you’ve printed you can get a settings object that represents the settings
  * the user chose, and the next time you print you can pass that object in so
- * that the user doesn't have to re-set all his settings.
+ * that the user doesn’t have to re-set all his settings.
  *
  * Its also possible to enumerate the settings so that you can easily save
  * the settings for the next time your app runs, or even store them in a
@@ -241,7 +241,7 @@ gtk_print_settings_has_key (GtkPrintSettings *settings,
  * Returns the boolean represented by the value
  * that is associated with @key. 
  *
- * The string "true" represents %TRUE, any other 
+ * The string “true” represents %TRUE, any other 
  * string %FALSE.
  *
  * Return value: %TRUE, if @key maps to a true value.
@@ -271,8 +271,8 @@ gtk_print_settings_get_bool (GtkPrintSettings *settings,
  * that is associated with @key, or @default_val
  * if the value does not represent a boolean.
  *
- * The string "true" represents %TRUE, the string
- * "false" represents %FALSE.
+ * The string “true” represents %TRUE, the string
+ * “false” represents %FALSE.
  *
  * Return value: the boolean value associated with @key
  * 
@@ -816,8 +816,9 @@ gtk_print_settings_set_use_color (GtkPrintSettings *settings,
 gboolean
 gtk_print_settings_get_collate (GtkPrintSettings *settings)
 {
-  return gtk_print_settings_get_bool (settings, 
-				      GTK_PRINT_SETTINGS_COLLATE);
+  return gtk_print_settings_get_bool_with_default (settings,
+                                                   GTK_PRINT_SETTINGS_COLLATE,
+                                                   TRUE);
 }
 
 /**
@@ -1434,7 +1435,7 @@ gtk_print_settings_set_print_pages (GtkPrintSettings *settings,
  * Gets the value of %GTK_PRINT_SETTINGS_PAGE_RANGES.
  *
  * Return value: (array length=num_ranges) (transfer full): an array
- *     of #GtkPageRange<!-- -->s.  Use g_free() to free the array when
+ *     of #GtkPageRanges.  Use g_free() to free the array when
  *     it is no longer needed.
  *
  * Since: 2.10
@@ -1492,7 +1493,7 @@ gtk_print_settings_get_page_ranges (GtkPrintSettings *settings,
 /**
  * gtk_print_settings_set_page_ranges:
  * @settings: a #GtkPrintSettings
- * @page_ranges: (array length=num_ranges): an array of #GtkPageRange<!-- -->s
+ * @page_ranges: (array length=num_ranges): an array of #GtkPageRanges
  * @num_ranges: the length of @page_ranges
  * 
  * Sets the value of %GTK_PRINT_SETTINGS_PAGE_RANGES.
@@ -1764,7 +1765,7 @@ gtk_print_settings_new_from_file (const gchar  *file_name,
  * @settings: a #GtkPrintSettings
  * @key_file: the #GKeyFile to retrieve the settings from
  * @group_name: (allow-none): the name of the group to use, or %NULL to use the default
- *     "Print Settings"
+ *     “Print Settings”
  * @error: (allow-none): return location for errors, or %NULL
  * 
  * Reads the print settings from the group @group_name in @key_file. If the
@@ -1825,7 +1826,7 @@ gtk_print_settings_load_key_file (GtkPrintSettings *settings,
  * gtk_print_settings_new_from_key_file:
  * @key_file: the #GKeyFile to retrieve the settings from
  * @group_name: (allow-none): the name of the group to use, or %NULL to use
- *     the default "Print Settings"
+ *     the default “Print Settings”
  * @error: (allow-none): return location for errors, or %NULL
  *
  * Reads the print settings from the group @group_name in @key_file.  Returns a
@@ -1919,7 +1920,7 @@ add_value_to_key_file (const gchar  *key,
  * @settings: a #GtkPrintSettings
  * @key_file: the #GKeyFile to save the print settings to
  * @group_name: the group to add the settings to in @key_file, or 
- *     %NULL to use the default "Print Settings"
+ *     %NULL to use the default “Print Settings”
  *
  * This function adds the print settings from @settings to @key_file.
  * 
