@@ -488,11 +488,10 @@ gtk_recent_chooser_menu_set_current_uri (GtkRecentChooser  *chooser,
   GList *children, *l;
   GtkWidget *menu_item = NULL;
   gboolean found = FALSE;
-  gint i = 0;
   
   children = gtk_container_get_children (GTK_CONTAINER (menu));
   
-  for (l = children; l != NULL; l = l->next, i++)
+  for (l = children; l != NULL; l = l->next)
     {
       GtkRecentInfo *info;
       
@@ -504,7 +503,9 @@ gtk_recent_chooser_menu_set_current_uri (GtkRecentChooser  *chooser,
       
       if (strcmp (uri, gtk_recent_info_get_uri (info)) == 0)
         {
-          gtk_menu_set_active (GTK_MENU (menu), i);
+          gtk_menu_shell_activate_item (GTK_MENU_SHELL (menu),
+	                                menu_item,
+					TRUE);
 	  found = TRUE;
 
 	  break;
@@ -1112,9 +1113,7 @@ item_activate_cb (GtkWidget *widget,
 		  gpointer   user_data)
 {
   GtkRecentChooser *chooser = GTK_RECENT_CHOOSER (user_data);
-  GtkRecentInfo *info = g_object_get_data (G_OBJECT (widget), "gtk-recent-info");
-
-  gtk_recent_chooser_menu_set_current_uri (chooser, gtk_recent_info_get_uri (info), NULL);
+  
   _gtk_recent_chooser_item_activated (chooser);
 }
 
@@ -1306,7 +1305,7 @@ gtk_recent_chooser_menu_get_show_numbers (GtkRecentChooserMenu *menu)
  *
  * Sets whether a number should be added to the items of @menu.  The
  * numbers are shown to provide a unique character for a mnemonic to
- * be used inside ten menu item's label.  Only the first the items
+ * be used inside ten menu item’s label.  Only the first the items
  * get a number to avoid clashes.
  *
  * Since: 2.10
