@@ -73,8 +73,8 @@ static gboolean   gtk_separator_draw         (GtkWidget      *widget,
 
 
 G_DEFINE_TYPE_WITH_CODE (GtkSeparator, gtk_separator, GTK_TYPE_WIDGET,
-                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE,
-                                                NULL))
+                         G_ADD_PRIVATE (GtkSeparator)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL))
 
 
 static void
@@ -94,25 +94,18 @@ gtk_separator_class_init (GtkSeparatorClass *class)
   gtk_widget_class_set_accessible_role (widget_class, ATK_ROLE_SEPARATOR);
 
   g_object_class_override_property (object_class, PROP_ORIENTATION, "orientation");
-
-  g_type_class_add_private (object_class, sizeof (GtkSeparatorPrivate));
 }
 
 static void
 gtk_separator_init (GtkSeparator *separator)
 {
-  GtkSeparatorPrivate *private;
   GtkStyleContext *context;
 
-  separator->priv = G_TYPE_INSTANCE_GET_PRIVATE (separator,
-                                                 GTK_TYPE_SEPARATOR,
-                                                 GtkSeparatorPrivate);
-  private = separator->priv;
+  separator->priv = gtk_separator_get_instance_private (separator);
+  separator->priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 
   gtk_widget_set_has_window (GTK_WIDGET (separator), FALSE);
 
-  private->orientation = GTK_ORIENTATION_HORIZONTAL;
-
   context = gtk_widget_get_style_context (GTK_WIDGET (separator));
   gtk_style_context_add_class (context, GTK_STYLE_CLASS_SEPARATOR);
 }
@@ -167,17 +160,10 @@ gtk_separator_get_preferred_size (GtkWidget      *widget,
 {
   GtkSeparator *separator = GTK_SEPARATOR (widget);
   GtkSeparatorPrivate *private = separator->priv;
-  GtkStyleContext *context;
-  GtkStateFlags state;
-  GtkBorder border;
   gboolean wide_sep;
   gint     sep_width;
   gint     sep_height;
 
-  context = gtk_widget_get_style_context (widget);
-  state = gtk_widget_get_state_flags (widget);
-  gtk_style_context_get_border (context, state, &border);
-
   gtk_widget_style_get (widget,
                         "wide-separators",  &wide_sep,
                         "separator-width",  &sep_width,
@@ -190,11 +176,11 @@ gtk_separator_get_preferred_size (GtkWidget      *widget,
     }
   else if (orientation == GTK_ORIENTATION_VERTICAL)
     {
-      *minimum = *natural = wide_sep ? sep_height : border.top;
+      *minimum = *natural = wide_sep ? sep_height : 1;
     }
   else
     {
-      *minimum = *natural = wide_sep ? sep_width : border.left;
+      *minimum = *natural = wide_sep ? sep_width : 1;
     }
 }
 
@@ -220,27 +206,22 @@ gtk_separator_draw (GtkWidget *widget,
 {
   GtkSeparator *separator = GTK_SEPARATOR (widget);
   GtkSeparatorPrivate *private = separator->priv;
-  GtkStateFlags state;
   GtkStyleContext *context;
-  GtkBorder padding;
   gboolean wide_separators;
   gint separator_width;
   gint separator_height;
   int width, height;
 
-  context = gtk_widget_get_style_context (widget);
   gtk_widget_style_get (widget,
                         "wide-separators",  &wide_separators,
                         "separator-width",  &separator_width,
                         "separator-height", &separator_height,
                         NULL);
 
-  state = gtk_widget_get_state_flags (widget);
+  context = gtk_widget_get_style_context (widget);
   width = gtk_widget_get_allocated_width (widget);
   height = gtk_widget_get_allocated_height (widget);
 
-  gtk_style_context_get_padding (context, state, &padding);
-
   if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       if (wide_separators)
@@ -249,8 +230,8 @@ gtk_separator_draw (GtkWidget *widget,
                           width, separator_height);
       else
         gtk_render_line (context, cr,
-                         0, (height - padding.top) / 2,
-                         width - 1, (height - padding.top) / 2);
+                         0, height / 2,
+                         width - 1, height / 2);
     }
   else
     {
@@ -260,8 +241,8 @@ gtk_separator_draw (GtkWidget *widget,
                           separator_width, height);
       else
         gtk_render_line (context, cr,
-                         (width - padding.left) / 2, 0,
-                         (width - padding.left) / 2, height - 1);
+                         width / 2, 0,
+                         width / 2, height - 1);
     }
 
   return FALSE;
@@ -269,7 +250,7 @@ gtk_separator_draw (GtkWidget *widget,
 
 /**
  * gtk_separator_new:
- * @orientation: the separator's orientation.
+ * @orientation: the separator’s orientation.
  *
  * Creates a new #GtkSeparator with the given orientation.
  *
