@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  * Code adapted from egg-spinner
  * by Christian Hergert <christian.hergert@gmail.com>
@@ -31,10 +29,11 @@
 
 #include "config.h"
 
-#include "gtkintl.h"
-#include "gtkaccessible.h"
-#include "gtkimage.h"
 #include "gtkspinner.h"
+
+#include "gtkimage.h"
+#include "gtkintl.h"
+#include "gtkstylecontext.h"
 #include "a11y/gtkspinneraccessible.h"
 
 
@@ -53,7 +52,7 @@
  */
 
 
-#define SPINNER_SIZE 12
+#define SPINNER_SIZE 16
 
 enum {
   PROP_0,
@@ -85,7 +84,7 @@ static void gtk_spinner_get_preferred_height (GtkWidget *widget,
                                         gint            *natural_size);
 
 
-G_DEFINE_TYPE (GtkSpinner, gtk_spinner, GTK_TYPE_WIDGET)
+G_DEFINE_TYPE_WITH_PRIVATE (GtkSpinner, gtk_spinner, GTK_TYPE_WIDGET)
 
 static void
 gtk_spinner_class_init (GtkSpinnerClass *klass)
@@ -94,7 +93,6 @@ gtk_spinner_class_init (GtkSpinnerClass *klass)
   GtkWidgetClass *widget_class;
 
   gobject_class = G_OBJECT_CLASS(klass);
-  g_type_class_add_private (gobject_class, sizeof (GtkSpinnerPrivate));
   gobject_class->get_property = gtk_spinner_get_property;
   gobject_class->set_property = gtk_spinner_set_property;
 
@@ -159,13 +157,9 @@ gtk_spinner_set_property (GObject      *object,
 static void
 gtk_spinner_init (GtkSpinner *spinner)
 {
-  GtkSpinnerPrivate *priv;
   GtkStyleContext *context;
 
-  priv = G_TYPE_INSTANCE_GET_PRIVATE (spinner,
-                                      GTK_TYPE_SPINNER,
-                                      GtkSpinnerPrivate);
-  spinner->priv = priv;
+  spinner->priv = gtk_spinner_get_instance_private (spinner);
 
   gtk_widget_set_has_window (GTK_WIDGET (spinner), FALSE);
 
@@ -202,12 +196,25 @@ gtk_spinner_draw (GtkWidget *widget,
                   cairo_t   *cr)
 {
   GtkStyleContext *context;
+  gint width, height;
+  gint size;
 
   context = gtk_widget_get_style_context (widget);
 
-  gtk_render_activity (context, cr, 0, 0,
-                       gtk_widget_get_allocated_width (widget),
-                       gtk_widget_get_allocated_height (widget));
+  width = gtk_widget_get_allocated_width (widget);
+  height = gtk_widget_get_allocated_height (widget);
+  size = MIN (width, height);
+
+  /* at most allow a double size spinner */
+  if (size >= 3 * SPINNER_SIZE)
+    size = SPINNER_SIZE * 2;
+  else
+    size = SPINNER_SIZE;
+
+  gtk_render_activity (context, cr,
+                       (width - size) / 2,
+                       (height - size) / 2,
+                       size, size);
 
   return FALSE;
 }
