@@ -25,7 +25,7 @@
 
 /**
  * SECTION:gtkswitch
- * @Short_Description: A "light switch" style toggle
+ * @Short_Description: A “light switch” style toggle
  * @Title: GtkSwitch
  * @See_Also: #GtkToggleButton
  *
@@ -894,6 +894,7 @@ gtk_switch_class_init (GtkSwitchClass *klass)
   g_object_class_override_property (gobject_class, PROP_ACTION_TARGET, "action-target");
 
   gtk_widget_class_set_accessible_type (widget_class, GTK_TYPE_SWITCH_ACCESSIBLE);
+  gtk_widget_class_set_accessible_role (widget_class, ATK_ROLE_TOGGLE_BUTTON);
 }
 
 static void
@@ -973,7 +974,7 @@ gtk_switch_set_active (GtkSwitch *sw,
  * gtk_switch_get_active:
  * @sw: a #GtkSwitch
  *
- * Gets whether the #GtkSwitch is in its "on" or "off" state.
+ * Gets whether the #GtkSwitch is in its “on” or “off” state.
  *
  * Return value: %TRUE if the #GtkSwitch is active, and %FALSE otherwise
  *
