@@ -103,7 +103,7 @@ gtk_text_line_segment_split (const GtkTextIter *iter)
 
   count = gtk_text_iter_get_line_index (iter);
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     _gtk_text_iter_check (iter);
   
   prev = NULL;
@@ -194,7 +194,7 @@ _gtk_char_segment_new (const gchar *text, guint len)
 
   g_assert (gtk_text_byte_begins_utf8_char (text));
 
-  seg = g_slice_alloc (CSEG_SIZE (len));
+  seg = g_malloc (CSEG_SIZE (len));
   seg->type = (GtkTextLineSegmentClass *)&gtk_text_char_type;
   seg->next = NULL;
   seg->byte_count = len;
@@ -203,7 +203,7 @@ _gtk_char_segment_new (const gchar *text, guint len)
 
   seg->char_count = g_utf8_strlen (seg->body.chars, seg->byte_count);
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     char_segment_self_check (seg);
 
   return seg;
@@ -222,7 +222,7 @@ _gtk_char_segment_new_from_two_strings (const gchar *text1,
   g_assert (gtk_text_byte_begins_utf8_char (text1));
   g_assert (gtk_text_byte_begins_utf8_char (text2));
 
-  seg = g_slice_alloc (CSEG_SIZE (len1+len2));
+  seg = g_malloc (CSEG_SIZE (len1+len2));
   seg->type = &gtk_text_char_type;
   seg->next = NULL;
   seg->byte_count = len1 + len2;
@@ -232,23 +232,12 @@ _gtk_char_segment_new_from_two_strings (const gchar *text1,
 
   seg->char_count = chars1 + chars2;
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     char_segment_self_check (seg);
 
   return seg;
 }
 
-static void
-_gtk_char_segment_free (GtkTextLineSegment *seg)
-{
-  if (seg == NULL)
-    return;
-
-  g_assert (seg->type == &gtk_text_char_type);
-
-  g_slice_free1 (CSEG_SIZE (seg->byte_count), seg);
-}
-
 /*
  *--------------------------------------------------------------
  *
@@ -274,7 +263,7 @@ char_segment_split_func (GtkTextLineSegment *seg, int index)
 
   g_assert (index < seg->byte_count);
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     {
       char_segment_self_check (seg);
     }
@@ -290,13 +279,13 @@ char_segment_split_func (GtkTextLineSegment *seg, int index)
   new1->next = new2;
   new2->next = seg->next;
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     {
       char_segment_self_check (new1);
       char_segment_self_check (new2);
     }
 
-  _gtk_char_segment_free (seg);
+  g_free (seg);
   return new1;
 }
 
@@ -329,7 +318,7 @@ char_segment_cleanup_func (GtkTextLineSegment *segPtr, GtkTextLine *line)
 {
   GtkTextLineSegment *segPtr2, *newPtr;
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     char_segment_self_check (segPtr);
 
   segPtr2 = segPtr->next;
@@ -348,11 +337,11 @@ char_segment_cleanup_func (GtkTextLineSegment *segPtr, GtkTextLine *line)
 
   newPtr->next = segPtr2->next;
 
-  if (GTK_DEBUG_CHECK (TEXT))
+  if (gtk_get_debug_flags () & GTK_DEBUG_TEXT)
     char_segment_self_check (newPtr);
 
-  _gtk_char_segment_free (segPtr);
-  _gtk_char_segment_free (segPtr2);
+  g_free (segPtr);
+  g_free (segPtr2);
   return newPtr;
 }
 
@@ -382,7 +371,7 @@ char_segment_cleanup_func (GtkTextLineSegment *segPtr, GtkTextLine *line)
 static int
 char_segment_delete_func (GtkTextLineSegment *segPtr, GtkTextLine *line, int treeGone)
 {
-  _gtk_char_segment_free (segPtr);
+  g_free ((char*) segPtr);
   return 0;
 }
 
@@ -428,7 +417,7 @@ _gtk_toggle_segment_new (GtkTextTagInfo *info, gboolean on)
 {
   GtkTextLineSegment *seg;
 
-  seg = g_slice_alloc (TSEG_SIZE);
+  seg = g_malloc (TSEG_SIZE);
 
   seg->type = on ? &gtk_text_toggle_on_type : &gtk_text_toggle_off_type;
 
@@ -443,18 +432,6 @@ _gtk_toggle_segment_new (GtkTextTagInfo *info, gboolean on)
   return seg;
 }
 
-void
-_gtk_toggle_segment_free (GtkTextLineSegment *seg)
-{
-  if (seg == NULL)
-    return;
-
-  g_assert (seg->type == &gtk_text_toggle_on_type ||
-            seg->type == &gtk_text_toggle_off_type);
-
-  g_slice_free1 (TSEG_SIZE, seg);
-}
-
 /*
  *--------------------------------------------------------------
  *
@@ -485,7 +462,7 @@ toggle_segment_delete_func (GtkTextLineSegment *segPtr, GtkTextLine *line, int t
 {
   if (treeGone)
     {
-      _gtk_toggle_segment_free (segPtr);
+      g_free ((char *) segPtr);
       return 0;
     }
 
@@ -568,9 +545,9 @@ toggle_segment_cleanup_func (GtkTextLineSegment *segPtr, GtkTextLine *line)
                                              segPtr->body.toggle.info, -counts);
             }
           prevPtr->next = segPtr2->next;
-          _gtk_toggle_segment_free (segPtr2);
+          g_free ((char *) segPtr2);
           segPtr2 = segPtr->next;
-          _gtk_toggle_segment_free (segPtr);
+          g_free ((char *) segPtr);
           return segPtr2;
         }
     }
