@@ -73,6 +73,14 @@ static void      gtk_tree_menu_get_preferred_width            (GtkWidget
 static void      gtk_tree_menu_get_preferred_height           (GtkWidget           *widget,
                                                                gint                *minimum_size,
                                                                gint                *natural_size);
+static void      gtk_tree_menu_get_preferred_width_for_height (GtkWidget           *widget,
+                                                               gint                 for_height,
+                                                               gint                *minimum_size,
+                                                               gint                *natural_size);
+static void      gtk_tree_menu_get_preferred_height_for_width (GtkWidget           *widget,
+                                                               gint                 for_width,
+                                                               gint                *minimum_size,
+                                                               gint                *natural_size);
 
 /* GtkCellLayoutIface */
 static void      gtk_tree_menu_cell_layout_init               (GtkCellLayoutIface  *iface);
@@ -227,6 +235,8 @@ _gtk_tree_menu_class_init (GtkTreeMenuClass *class)
 
   widget_class->get_preferred_width  = gtk_tree_menu_get_preferred_width;
   widget_class->get_preferred_height = gtk_tree_menu_get_preferred_height;
+  widget_class->get_preferred_width_for_height  = gtk_tree_menu_get_preferred_width_for_height;
+  widget_class->get_preferred_height_for_width = gtk_tree_menu_get_preferred_height_for_width;
 
   /*
    * GtkTreeMenu::menu-activate:
@@ -617,6 +627,49 @@ gtk_tree_menu_get_preferred_height (GtkWidget           *widget,
   g_signal_handler_unblock (priv->context, priv->size_changed_id);
 }
 
+static void
+gtk_tree_menu_get_preferred_width_for_height (GtkWidget           *widget,
+                                              gint                 for_height,
+                                              gint                *minimum_size,
+                                              gint                *natural_size)
+{
+  GtkTreeMenu        *menu = GTK_TREE_MENU (widget);
+  GtkTreeMenuPrivate *priv = menu->priv;
+
+  /* We leave the requesting work up to the cellviews which operate in the same
+   * context, reserving space for the submenu indicator if any of the items have
+   * submenus ensures that every cellview will receive the same allocated width.
+   *
+   * Since GtkMenu does hieght-for-width correctly, we know that the width of
+   * every cell will be requested before the height-for-widths are requested.
+   */
+  g_signal_handler_block (priv->context, priv->size_changed_id);
+
+  sync_reserve_submenu_size (menu);
+
+  GTK_WIDGET_CLASS (_gtk_tree_menu_parent_class)->get_preferred_width_for_height (widget, for_height, minimum_size, natural_size);
+
+  g_signal_handler_unblock (priv->context, priv->size_changed_id);
+}
+
+static void
+gtk_tree_menu_get_preferred_height_for_width (GtkWidget           *widget,
+                                              gint                 for_width,
+                                              gint                *minimum_size,
+                                              gint                *natural_size)
+{
+  GtkTreeMenu        *menu = GTK_TREE_MENU (widget);
+  GtkTreeMenuPrivate *priv = menu->priv;
+
+  g_signal_handler_block (priv->context, priv->size_changed_id);
+
+  sync_reserve_submenu_size (menu);
+
+  GTK_WIDGET_CLASS (_gtk_tree_menu_parent_class)->get_preferred_height_for_width (widget, for_width, minimum_size, natural_size);
+
+  g_signal_handler_unblock (priv->context, priv->size_changed_id);
+}
+
 /****************************************************************
  *                      GtkCellLayoutIface                      *
  ****************************************************************/
@@ -1591,7 +1644,7 @@ _gtk_tree_menu_set_model (GtkTreeMenu  *menu,
  * Gets the @model currently used for the menu heirarhcy.
  *
  * Return value: (transfer none): the #GtkTreeModel which is used
- * for @menu's hierarchy.
+ * for @menu’s hierarchy.
  *
  * Since: 3.0
  */
@@ -1612,7 +1665,7 @@ _gtk_tree_menu_get_model (GtkTreeMenu *menu)
  * @menu: a #GtkTreeMenu
  * @path: (allow-none): the #GtkTreePath which is the root of @menu, or %NULL.
  *
- * Sets the root of a @menu's hierarchy to be @path. @menu must already
+ * Sets the root of a @menu’s hierarchy to be @path. @menu must already
  * have a model set and @path must point to a valid path inside the model.
  *
  * Since: 3.0
@@ -1643,7 +1696,7 @@ _gtk_tree_menu_set_root (GtkTreeMenu *menu,
  * _gtk_tree_menu_get_root:
  * @menu: a #GtkTreeMenu
  *
- * Gets the @root path for @menu's hierarchy, or returns %NULL if @menu
+ * Gets the @root path for @menu’s hierarchy, or returns %NULL if @menu
  * has no model or is building a heirarchy for the entire model. *
  *
  * Return value: (transfer full) (allow-none): A newly created #GtkTreePath
@@ -1779,7 +1832,7 @@ _gtk_tree_menu_set_wrap_width (GtkTreeMenu *menu,
  * The row span column contains integers which indicate how many rows
  * a menu item should span.
  *
- * Return value: the column in @menu's model containing row span information, or -1.
+ * Return value: the column in @menu’s model containing row span information, or -1.
  *
  * Since: 3.0
  */
@@ -1835,7 +1888,7 @@ _gtk_tree_menu_set_row_span_column (GtkTreeMenu *menu,
  * The column span column contains integers which indicate how many columns
  * a menu item should span.
  *
- * Return value: the column in @menu's model containing column span information, or -1.
+ * Return value: the column in @menu’s model containing column span information, or -1.
  *
  * Since: 3.0
  */
