@@ -45,13 +45,13 @@
  * @See_also: #GtkTreeView, #GtkTreeSelection, #GtkTreeModel, #GtkTreeSortable,
  *   #GtkTreeModelSort, #GtkListStore, #GtkTreeStore, #GtkCellRenderer, #GtkCellEditable,
  *   #GtkCellRendererPixbuf, #GtkCellRendererText, #GtkCellRendererToggle,
- *   <link linkend="gtk3-GtkTreeView-drag-and-drop">GtkTreeView drag-and-drop</link>
+ *   [GtkTreeView drag-and-drop][gtk3-GtkTreeView-drag-and-drop]
  *
  * The GtkTreeViewColumn object represents a visible column in a #GtkTreeView widget.
  * It allows to set properties of the column header, and functions as a holding pen for
  * the cell renderers which determine how the data in the column is displayed.
  *
- * Please refer to the <link linkend="TreeWidget">tree widget conceptual overview</link>
+ * Please refer to the [tree widget conceptual overview][TreeWidget]
  * for an overview of all the objects and data types related to the tree widget and how
  * they work together.
  */
@@ -1652,7 +1652,7 @@ gtk_tree_view_column_new_with_area (GtkCellArea *area)
  * gtk_tree_view_column_pack_start(), and
  * gtk_tree_view_column_set_attributes() on the newly created #GtkTreeViewColumn.
  *
- * Here's a simple example:
+ * Here’s a simple example:
  * |[<!-- language="C" -->
  *  enum { TEXT_COLUMN, COLOR_COLUMN, N_COLUMNS };
  *  ...
@@ -1749,7 +1749,7 @@ gtk_tree_view_column_clear (GtkTreeViewColumn *tree_column)
  * column of the model to get a value from, and the @attribute is the
  * parameter on @cell_renderer to be set from the value. So for example
  * if column 2 of the model contains strings, you could have the
- * "text" attribute of a #GtkCellRendererText get its values from
+ * “text” attribute of a #GtkCellRendererText get its values from
  * column 2.
  **/
 void
@@ -1788,7 +1788,7 @@ gtk_tree_view_column_set_attributesv (GtkTreeViewColumn *tree_column,
 /**
  * gtk_tree_view_column_set_attributes:
  * @tree_column: A #GtkTreeViewColumn
- * @cell_renderer: the #GtkCellRenderer we're setting the attributes of
+ * @cell_renderer: the #GtkCellRenderer we’re setting the attributes of
  * @...: A %NULL-terminated list of attributes
  *
  * Sets the attributes in the list as the attributes of @tree_column.
@@ -2184,13 +2184,13 @@ _gtk_tree_view_column_allocate (GtkTreeViewColumn *tree_column,
  * If @fixed_width is not -1, sets the fixed width of @tree_column; otherwise
  * unsets it.  The effective value of @fixed_width is clamped between the
  * minumum and maximum width of the column; however, the value stored in the
- * "fixed-width" property is not clamped.  If the column sizing is 
+ * “fixed-width” property is not clamped.  If the column sizing is 
  * #GTK_TREE_VIEW_COLUMN_GROW_ONLY or #GTK_TREE_VIEW_COLUMN_AUTOSIZE, setting a
  * fixed width overrides the automatically calculated width.  Note that
  * @fixed_width is only a hint to GTK+; the width actually allocated to the
  * column may be greater or less than requested.
  *
- * Along with "expand", the "fixed-width" property changes when the column is
+ * Along with “expand”, the “fixed-width” property changes when the column is
  * resized by the user.
  **/
 void
@@ -2273,7 +2273,7 @@ gtk_tree_view_column_set_min_width (GtkTreeViewColumn *tree_column,
   g_object_notify (G_OBJECT (tree_column), "min-width");
   g_object_thaw_notify (G_OBJECT (tree_column));
 
-  if (priv->column_type == GTK_TREE_VIEW_COLUMN_AUTOSIZE)
+  if (priv->column_type == GTK_TREE_VIEW_COLUMN_AUTOSIZE && priv->tree_view)
     _gtk_tree_view_column_autosize (GTK_TREE_VIEW (priv->tree_view),
 				    tree_column);
 }
@@ -2302,7 +2302,7 @@ gtk_tree_view_column_get_min_width (GtkTreeViewColumn *tree_column)
  * 
  * Sets the maximum width of the @tree_column.  If @max_width is -1, then the
  * maximum width is unset.  Note, the column can actually be wider than max
- * width if it's the last column in a view.  In this case, the column expands to
+ * width if it’s the last column in a view.  In this case, the column expands to
  * fill any extra space.
  **/
 void
@@ -2337,7 +2337,7 @@ gtk_tree_view_column_set_max_width (GtkTreeViewColumn *tree_column,
   g_object_notify (G_OBJECT (tree_column), "max-width");
   g_object_thaw_notify (G_OBJECT (tree_column));
 
-  if (priv->column_type == GTK_TREE_VIEW_COLUMN_AUTOSIZE)
+  if (priv->column_type == GTK_TREE_VIEW_COLUMN_AUTOSIZE && priv->tree_view)
     _gtk_tree_view_column_autosize (GTK_TREE_VIEW (priv->tree_view),
 				    tree_column);
 }
@@ -2363,7 +2363,7 @@ gtk_tree_view_column_get_max_width (GtkTreeViewColumn *tree_column)
  * gtk_tree_view_column_clicked:
  * @tree_column: a #GtkTreeViewColumn
  * 
- * Emits the "clicked" signal on the column.  This function will only work if
+ * Emits the “clicked” signal on the column.  This function will only work if
  * @tree_column is clickable.
  **/
 void
@@ -2435,7 +2435,7 @@ gtk_tree_view_column_get_title (GtkTreeViewColumn *tree_column)
  * option set, then the last column gets all extra space.  By default, every
  * column is created with this %FALSE.
  *
- * Along with "fixed-width", the "expand" property changes when the column is
+ * Along with “fixed-width”, the “expand” property changes when the column is
  * resized by the user.
  *
  * Since: 2.4
@@ -2735,7 +2735,7 @@ gtk_tree_view_column_set_sort_column_id (GtkTreeViewColumn *tree_column,
  * See gtk_tree_view_column_set_sort_column_id().
  *
  * Return value: the current @sort_column_id for this column, or -1 if
- *               this column can't be used for sorting.
+ *               this column can’t be used for sorting.
  **/
 gint
 gtk_tree_view_column_get_sort_column_id (GtkTreeViewColumn *tree_column)
@@ -2839,7 +2839,7 @@ gtk_tree_view_column_get_sort_order      (GtkTreeViewColumn     *tree_column)
  * gtk_tree_view_column_cell_set_cell_data:
  * @tree_column: A #GtkTreeViewColumn.
  * @tree_model: The #GtkTreeModel to to get the cell renderers attributes from.
- * @iter: The #GtkTreeIter to to get the cell renderer's attributes from.
+ * @iter: The #GtkTreeIter to to get the cell renderer’s attributes from.
  * @is_expander: %TRUE, if the row has children
  * @is_expanded: %TRUE, if the row has visible children
  * 
