@@ -219,7 +219,7 @@ output_file_from_settings (GtkPrintSettings *settings,
 
   if (uri == NULL)
     { 
-      const gchar *extension, *basename, *output_dir;
+      const gchar *extension, *basename = NULL, *output_dir = NULL;
       gchar *name, *locale_name, *path;
 
       if (default_format)
@@ -244,7 +244,8 @@ output_file_from_settings (GtkPrintSettings *settings,
             }
         }
 
-      basename = gtk_print_settings_get (settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME);
+      if (settings)
+        basename = gtk_print_settings_get (settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME);
       if (basename == NULL)
         basename = _("output");
 
@@ -254,8 +255,9 @@ output_file_from_settings (GtkPrintSettings *settings,
       g_free (name);
 
       if (locale_name != NULL)
-        {      
-          output_dir = gtk_print_settings_get (settings, GTK_PRINT_SETTINGS_OUTPUT_DIR);
+        {
+          if (settings)
+            output_dir = gtk_print_settings_get (settings, GTK_PRINT_SETTINGS_OUTPUT_DIR);
           if (output_dir == NULL)
             {
               const gchar *document_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS);
@@ -382,7 +384,10 @@ file_print_cb_locked (GtkPrintBackendFile *print_backend,
                       GError              *error,
                       gpointer            user_data)
 {
+  gchar *uri;
+
   _PrintStreamData *ps = (_PrintStreamData *) user_data;
+  GtkRecentManager *recent_manager;
 
   if (ps->target_io_stream != NULL)
     g_output_stream_close (G_OUTPUT_STREAM (ps->target_io_stream), NULL, NULL);
@@ -396,6 +401,11 @@ file_print_cb_locked (GtkPrintBackendFile *print_backend,
   gtk_print_job_set_status (ps->job,
 			    (error != NULL)?GTK_PRINT_STATUS_FINISHED_ABORTED:GTK_PRINT_STATUS_FINISHED);
 
+  recent_manager = gtk_recent_manager_get_default ();
+  uri = output_file_from_settings (gtk_print_job_get_settings (ps->job), NULL);
+  gtk_recent_manager_add_item (recent_manager, uri);
+  g_free (uri);
+
   if (ps->job)
     g_object_unref (ps->job);
 
