@@ -15,9 +15,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <gtk/gtk.h>
@@ -39,8 +37,8 @@ static GtkWidget *test_widgets[TEST_WIDGET_LAST];
 static GtkWidget*
 create_image (void)
 {
-  return gtk_image_new_from_stock (GTK_STOCK_OPEN,
-                                   GTK_ICON_SIZE_BUTTON);
+  return gtk_image_new_from_icon_name ("document-open",
+                                       GTK_ICON_SIZE_BUTTON);
 }
 
 static GtkWidget*
@@ -356,8 +354,8 @@ open_margin_window (void)
   GtkWidget *box;
   int i;
   const char * margins[] = {
-    "margin-left",
-    "margin-right",
+    "margin-start",
+    "margin-end",
     "margin-top",
     "margin-bottom",
     "margin"
